@@ -74,7 +74,21 @@ async def worker_serve(
         tasks.append(loop.create_task(_windows_signal_support()))
 
     if shutdown_trigger is None:
-        shutdown_trigger = asyncio.Future
+        signal_event = asyncio.Event()
+
+        def _signal_handler(*_: Any) -> None:  # noqa: N803
+            signal_event.set()
+
+        for signal_name in {"SIGINT", "SIGTERM", "SIGBREAK"}:
+            if hasattr(signal, signal_name):
+                try:
+                    loop.add_signal_handler(getattr(signal, signal_name), _signal_handler)
+                except NotImplementedError:
+                    # Add signal handler may not be implemented on Windows
+                    signal.signal(getattr(signal, signal_name), _signal_handler)
+
+        shutdown_trigger = signal_event.wait  # type: ignore
+
     tasks.append(loop.create_task(raise_shutdown(shutdown_trigger)))
 
     if config.use_reloader:
@@ -118,6 +132,8 @@ async def worker_serve(
         bind = repr_socket_addr(sock.family, sock.getsockname())
         await config.log.info(f"Running on {bind} over http (CTRL + C to quit)")
 
+    tasks.extend(server.serve_forever() for server in servers)  # type: ignore
+
     for sock in sockets.quic_sockets:
         if config.workers > 1 and platform.system() == "Windows":
             sock = _share_socket(sock)
@@ -130,7 +146,6 @@ async def worker_serve(
     try:
         gathered_tasks = asyncio.gather(*tasks)
         await gathered_tasks
-
     except MustReloadException:
         reload_ = True
     except (Shutdown, KeyboardInterrupt):
@@ -210,21 +225,6 @@ def _run(
     loop.set_debug(debug)
     loop.set_exception_handler(_exception_handler)
 
-    if shutdown_trigger is None:
-        signal_event = asyncio.Event()
-
-        def _signal_handler(*_: Any) -> None:  # noqa: N803
-            signal_event.set()
-
-        for signal_ in [signal.SIGINT, signal.SIGTERM]:
-            try:
-                loop.add_signal_handler(signal_, _signal_handler)
-            except NotImplementedError:
-                # Add signal handler may not be implemented on Windows
-                signal.signal(signal_, _signal_handler)
-
-        shutdown_trigger = signal_event.wait  # type: ignore
-
     try:
         loop.run_until_complete(main(shutdown_trigger=shutdown_trigger))
     finally:
