@@ -22,6 +22,7 @@ OCTETS = 1
 SECONDS = 1.0
 
 FilePath = Union[AnyStr, os.PathLike]
+SocketKind = Union[int, socket.SocketKind]
 
 
 @dataclass
@@ -31,10 +32,19 @@ class Sockets:
     quic_sockets: List[socket.socket]
 
 
+class SocketTypeError(Exception):
+    def __init__(self, expected: SocketKind, actual: SocketKind) -> None:
+        super().__init__(
+            f'Unexpected socket type, wanted "{socket.SocketKind(expected)}" got '
+            f'"{socket.SocketKind(actual)}"'
+        )
+
+
 class Config:
     _bind = ["127.0.0.1:8000"]
     _insecure_bind: List[str] = []
     _quic_bind: List[str] = []
+    _quic_addresses: List[Tuple] = []
     _log: Optional[Logger] = None
 
     access_log_format = '%(h)s %(l)s %(l)s %(t)s "%(r)s" %(s)s %(b)s "%(f)s" "%(a)s"'
@@ -61,7 +71,7 @@ class Config:
     logconfig: Optional[str] = None
     logconfig_dict: Optional[dict] = None
     logger_class = Logger
-    loglevel: str = "info"
+    loglevel: Optional[str] = None
     max_app_queue_size: int = 10
     pid_path: Optional[str] = None
     root_path = ""
@@ -161,12 +171,25 @@ class Config:
             secure_sockets = self._create_sockets(self.bind)
             insecure_sockets = self._create_sockets(self.insecure_bind)
             quic_sockets = self._create_sockets(self.quic_bind, socket.SOCK_DGRAM)
+            self._set_quic_addresses(quic_sockets)
         else:
             secure_sockets = []
             insecure_sockets = self._create_sockets(self.bind)
             quic_sockets = []
         return Sockets(secure_sockets, insecure_sockets, quic_sockets)
 
+    def _set_quic_addresses(self, sockets: List[socket.socket]) -> None:
+        self._quic_addresses = []
+        for sock in sockets:
+            name = sock.getsockname()
+            if type(name) is not str and len(name) >= 2:
+                self._quic_addresses.append(name)
+            else:
+                warnings.warn(
+                    f'Cannot create a alt-svc header for the QUIC socket with address "{name}"',
+                    Warning,
+                )
+
     def _create_sockets(
         self, binds: List[str], type_: int = socket.SOCK_STREAM
     ) -> List[socket.socket]:
@@ -182,7 +205,10 @@ class Config:
                 except FileNotFoundError:
                     pass
             elif bind.startswith("fd://"):
-                sock = socket.fromfd(int(bind[5:]), socket.AF_UNIX, type_)
+                sock = socket.socket(fileno=int(bind[5:]))
+                actual_type = sock.getsockopt(socket.SOL_SOCKET, socket.SO_TYPE)
+                if actual_type != type_:
+                    raise SocketTypeError(type_, actual_type)
             else:
                 bind = bind.replace("[", "").replace("]", "")
                 try:
@@ -228,12 +254,12 @@ class Config:
 
         for alt_svc_header in self.alt_svc_headers:
             headers.append((b"alt-svc", alt_svc_header.encode()))
-        if len(self.alt_svc_headers) == 0 and self._quic_bind:
+        if len(self.alt_svc_headers) == 0 and self._quic_addresses:
             from aioquic.h3.connection import H3_ALPN
 
             for version in H3_ALPN:
-                for bind in self._quic_bind:
-                    port = int(bind.split(":")[-1])
+                for addr in self._quic_addresses:
+                    port = addr[1]
                     headers.append((b"alt-svc", b'%s=":%d"; ma=3600' % (version.encode(), port)))
 
         return headers
@@ -333,11 +359,9 @@ class Config:
         """
         if isinstance(instance, str):
             try:
-                path, config = instance.rsplit(".", 1)
-            except ValueError:
-                path = instance
                 instance = importlib.import_module(instance)
-            else:
+            except ImportError:
+                path, config = instance.rsplit(".", 1)  # type: ignore
                 module = importlib.import_module(path)
                 instance = getattr(module, config)
 
