@@ -2,8 +2,9 @@ import logging
 import os
 import sys
 import time
+from http import HTTPStatus
 from logging.config import dictConfig, fileConfig
-from typing import Any, Mapping, TYPE_CHECKING, Union
+from typing import Any, IO, Mapping, Optional, TYPE_CHECKING, Union
 
 if TYPE_CHECKING:
     from .config import Config
@@ -11,28 +12,12 @@ if TYPE_CHECKING:
 
 CONFIG_DEFAULTS = {
     "version": 1,
-    "disable_existing_loggers": False,
-    "root": {"level": "INFO", "handlers": ["console"]},
+    "root": {"level": "INFO", "handlers": ["error_console"]},
     "loggers": {
-        "hypercorn.error": {
-            "level": "INFO",
-            "handlers": ["error_console"],
-            "propagate": True,
-            "qualname": "hypercorn.error",
-        },
-        "hypercorn.access": {
-            "level": "INFO",
-            "handlers": ["console"],
-            "propagate": True,
-            "qualname": "hypercorn.access",
-        },
+        "hypercorn.error": {"qualname": "hypercorn.error"},
+        "hypercorn.access": {"level": "INFO", "propagate": False, "qualname": "hypercorn.access"},
     },
     "handlers": {
-        "console": {
-            "class": "logging.StreamHandler",
-            "formatter": "generic",
-            "stream": "ext://sys.stdout",
-        },
         "error_console": {
             "class": "logging.StreamHandler",
             "formatter": "generic",
@@ -50,45 +35,41 @@ CONFIG_DEFAULTS = {
 
 
 def _create_logger(
-    name: str, target: Union[logging.Logger, str, None], level: str, sys_default: Any
-) -> logging.Logger:
+    name: str, target: Union[logging.Logger, str, None], sys_default: IO
+) -> Optional[logging.Logger]:
     if isinstance(target, logging.Logger):
         return target
-    elif target is not None:
-        logger = logging.getLogger(name)
-        logger.propagate = False
-        logger.handlers = []
-        if target == "-":
-            logger.addHandler(logging.StreamHandler(sys_default))
-        else:
-            logger.addHandler(logging.FileHandler(target))
-        logger.setLevel(logging.getLevelName(level.upper()))
-        return logger
-    else:
-        return None
+
+    logger = logging.getLogger(name)
+    if target:
+        logger.handlers = [
+            logging.StreamHandler(sys_default) if target == "-" else logging.FileHandler(target)
+        ]
+
+    # hasHandlers() here will allow logger configuration from dict/file
+    return logger if logger.hasHandlers() else None
 
 
 class Logger:
     def __init__(self, config: "Config") -> None:
-        self.access_logger = _create_logger(
-            "hypercorn.access", config.accesslog, "info", sys.stdout
-        )
-        self.error_logger = _create_logger(
-            "hypercorn.error", config.errorlog, config.loglevel, sys.stderr
-        )
         self.access_log_format = config.access_log_format
 
-        if config.logconfig_dict is not None:
-            log_config = CONFIG_DEFAULTS.copy()
-            log_config.update(config.logconfig_dict)
+        log_config = CONFIG_DEFAULTS.copy()
+
+        if config.logconfig is not None:
+            log_config["__file__"] = config.logconfig
+            log_config["here"] = os.path.dirname(config.logconfig)
+            fileConfig(config.logconfig, defaults=log_config)  # type: ignore
+        else:
+            if config.logconfig_dict is not None:
+                log_config.update(config.logconfig_dict)
             dictConfig(log_config)
-        elif config.logconfig is not None:
-            defaults = CONFIG_DEFAULTS.copy()
-            defaults["__file__"] = config.logconfig
-            defaults["here"] = os.path.dirname(config.logconfig)
-            fileConfig(
-                config.logconfig, defaults=defaults, disable_existing_loggers=False  # type: ignore
-            )
+
+        self.access_logger = _create_logger("hypercorn.access", config.accesslog, sys.stdout)
+        self.error_logger = _create_logger("hypercorn.error", config.errorlog, sys.stderr)
+
+        if config.loglevel is not None:
+            logging.getLogger().setLevel(logging.getLevelName(config.loglevel.upper()))
 
     async def access(self, request: dict, response: dict, request_time: float) -> None:
         if self.access_logger is not None:
@@ -155,17 +136,22 @@ class AccessLogAtoms(dict):
         else:  # make sure not to throw UnboundLocalError
             remote_addr = f"<???{client}???>"
         method = request.get("method", "GET")
+        query_string = request["query_string"].decode()
+        path_with_qs = request["path"] + ("?" + query_string if query_string else "")
         self.update(
             {
                 "h": remote_addr,
                 "l": "-",
                 "t": time.strftime("[%d/%b/%Y:%H:%M:%S %z]"),
                 "r": f"{method} {request['path']} {protocol}",
+                "R": f"{method} {path_with_qs} {protocol}",
                 "s": response["status"],
+                "st": HTTPStatus(response["status"]).phrase,
                 "S": request["scheme"],
                 "m": method,
                 "U": request["path"],
-                "q": request["query_string"].decode(),
+                "Uq": path_with_qs,
+                "q": query_string,
                 "H": protocol,
                 "b": self["{Content-Length}o"],
                 "B": self["{Content-Length}o"],
